==> haskell-stmonadtrans-0.4.8.1-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 STMonadTrans
version:              0.4.8.1
visibility:           public
id:                   STMonadTrans-0.4.8.1-EvUzG9ukfg2InwrJ7svM1V
key:                  STMonadTrans-0.4.8.1-EvUzG9ukfg2InwrJ7svM1V
license:              BSD-3-Clause
maintainer:           Andreas Abel, josef.svenningsson@gmail.com
author:               Josef Svenningsson
homepage:             https://github.com/josefs/STMonadTrans
synopsis:             A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad.

    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.

category:             Monads
abi:                  1c30679e88726521cd6c0a1570b43e0e
exposed:              True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/STMonadTrans-0.4.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/STMonadTrans-0.4.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/STMonadTrans-0.4.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stmonadtrans
hs-libraries:         HSSTMonadTrans-0.4.8.1-EvUzG9ukfg2InwrJ7svM1V
depends:              array-0.5.4.0 base-4.17.2.1 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock

haddock-html:         /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stmonadtrans-0.4.8.1-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 STMonadTrans
version:              0.4.8.1
visibility:           public
id:                   STMonadTrans-0.4.8.1-4RV9zZEX9s0ArCcRA9j72j
key:                  STMonadTrans-0.4.8.1-4RV9zZEX9s0ArCcRA9j72j
license:              BSD-3-Clause
maintainer:           Andreas Abel, josef.svenningsson@gmail.com
author:               Josef Svenningsson
homepage:             https://github.com/josefs/STMonadTrans
synopsis:             A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad.

    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.

category:             Monads
abi:                  c069ca4ee1a34f26a5f86613a777a28b
exposed:              True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/STMonadTrans-0.4.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/STMonadTrans-0.4.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/STMonadTrans-0.4.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stmonadtrans
hs-libraries:         HSSTMonadTrans-0.4.8.1-4RV9zZEX9s0ArCcRA9j72j
depends:              array-0.5.4.0 base-4.17.2.1 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock

haddock-html:         /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
